==> qmmp-0.8.4.tar.bz2: qmmp-0.8.4/src/plugins/General/hal/translations/hal_plugin_fr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="fr_FR">
<context>
    <name>HalFactory</name>
    <message>
        <location filename="../halfactory.cpp" line="30"/>
        <source>HAL Plugin</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../halfactory.cpp" line="50"/>
        <source>About HAL Plugin</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../halfactory.cpp" line="51"/>
        <source>Qmmp HAL Plugin</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../halfactory.cpp" line="52"/>
        <source>This plugin provides removable devices detection using HAL</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../halfactory.cpp" line="53"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../halfactory.cpp" line="54"/>
        <source>Based on Solid (KDE hardware library)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>HalPlugin</name>
    <message>
        <location filename="../halplugin.cpp" line="160"/>
        <source>Add CD &quot;%1&quot;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../halplugin.cpp" line="166"/>
        <source>Add Volume &quot;%1&quot;</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="13"/>
        <source>HAL Plugin Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="28"/>
        <source>CD Audio Detection</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="37"/>
        <source>Add tracks to playlist automatically</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="44"/>
        <source>Remove tracks from playlist automatically</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="54"/>
        <source>Removable Device Detection</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="63"/>
        <source>Add files to playlist automatically</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="70"/>
        <source>Remove files from playlist automatically</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> qmmp-0.10.10.tar.bz2: qmmp-0.10.10/src/plugins/General/hal/translations/hal_plugin_fr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="fr">
<context>
    <name>HalFactory</name>
    <message>
        <location filename="../halfactory.cpp" line="32"/>
        <source>HAL Plugin</source>
        <translation>Greffon HAL</translation>
    </message>
    <message>
        <location filename="../halfactory.cpp" line="52"/>
        <source>About HAL Plugin</source>
        <translation>À propos du greffon HAL</translation>
    </message>
    <message>
        <location filename="../halfactory.cpp" line="53"/>
        <source>Qmmp HAL Plugin</source>
        <translation>Greffon HAL pour Qmmp</translation>
    </message>
    <message>
        <location filename="../halfactory.cpp" line="54"/>
        <source>This plugin provides removable devices detection using HAL</source>
        <translation>Ce greffon fournit une détection de périphériques amovibles en utilisant HAL</translation>
    </message>
    <message>
        <location filename="../halfactory.cpp" line="55"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>Écrit par : Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
    <message>
        <location filename="../halfactory.cpp" line="56"/>
        <source>Based on Solid (KDE hardware library)</source>
        <translation>Basé sur Solid (bibliothèque matérielle KDE)</translation>
    </message>
</context>
<context>
    <name>HalPlugin</name>
    <message>
        <location filename="../halplugin.cpp" line="160"/>
        <source>Add CD &quot;%1&quot;</source>
        <translation>Ajouter CD « %1 »</translation>
    </message>
    <message>
        <location filename="../halplugin.cpp" line="166"/>
        <source>Add Volume &quot;%1&quot;</source>
        <translation>Ajouter volume « %1 »</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="13"/>
        <source>HAL Plugin Settings</source>
        <translation>Configuration du greffon HAL</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="28"/>
        <source>CD Audio Detection</source>
        <translation>Détection de CD audio</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="37"/>
        <source>Add tracks to playlist automatically</source>
        <translation>Ajouter automatiquement les pistes à la liste</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="44"/>
        <source>Remove tracks from playlist automatically</source>
        <translation>Enlever automatiquement les pistes de la liste</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="54"/>
        <source>Removable Device Detection</source>
        <translation>Détection de périphérique amovible</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="63"/>
        <source>Add files to playlist automatically</source>
        <translation>Ajouter automatiquement les fichiers à la liste</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="70"/>
        <source>Remove files from playlist automatically</source>
        <translation>Enlever automatiquement les fichiers à la liste</translation>
    </message>
</context>
</TS>
